==> gnome-0.11.tar.gz: gnome-0.11/programs/gtt/menucmd.h <==
/*   GTimeTracker - a time tracker
 *   Copyright (C) 1997,98 Eckehard Berns
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __MENUCMD_H__
#define __MENUCMD_H__

void not_implemented(GtkWidget *w, gpointer data);

void quit_app(GtkWidget *, gpointer);
void about_box(GtkWidget *, gpointer);

void new_project(GtkWidget *, gpointer);
void init_project_list(GtkWidget *, gpointer);
void save_project_list(GtkWidget *, gpointer);
void cut_project(GtkWidget *w, gpointer data);
void paste_project(GtkWidget *w, gpointer data);
void copy_project(GtkWidget *w, gpointer data);

void menu_start_timer(GtkWidget *w, gpointer data);
void menu_stop_timer(GtkWidget *w, gpointer data);
void menu_toggle_timer(GtkWidget *w, gpointer data);

void menu_set_states(void);

void menu_options(GtkWidget *w, gpointer data);

void menu_properties(GtkWidget *w, gpointer data);


#ifdef GNOME_USE_MENU_INFO
void menu_create(GtkWidget *gnome_app);
#endif

#endif

==> gnome-0.12.tar.gz: gnome-0.12/programs/gtt/menucmd.h <==
/*   GTimeTracker - a time tracker
 *   Copyright (C) 1997,98 Eckehard Berns
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __MENUCMD_H__
#define __MENUCMD_H__


/* void not_implemented(GtkWidget *w, gpointer data); */

void quit_app(GtkWidget *, gpointer);
void about_box(GtkWidget *, gpointer);

void new_project(GtkWidget *, gpointer);
void init_project_list(GtkWidget *, gpointer);
void save_project_list(GtkWidget *, gpointer);
void cut_project(GtkWidget *w, gpointer data);
void paste_project(GtkWidget *w, gpointer data);
void copy_project(GtkWidget *w, gpointer data);

void menu_start_timer(GtkWidget *w, gpointer data);
void menu_stop_timer(GtkWidget *w, gpointer data);
void menu_toggle_timer(GtkWidget *w, gpointer data);

void menu_set_states(void);

void menu_options(GtkWidget *w, gpointer data);

void menu_properties(GtkWidget *w, gpointer data);

void menu_clear_daily_counter(GtkWidget *w, gpointer data);

#ifdef USE_GTT_HELP
void help_goto(char *helppos);
void menu_help_contents(GtkWidget *w, gpointer data);
#endif

#ifdef GNOME_USE_APP
void menu_create(GtkWidget *gnome_app);
#endif

#endif
